@@ -21,6 +21,8 @@ public:
 signals:
     void success();
     void error(QString msg);
+    void preparationStatusUpdate(QString msg);
+    void eventDriveFormat(quint32 durationMs, bool success);
 
 protected:
     QByteArray _device;
