@@ -56,7 +56,12 @@ void AcceleratedCryptographicHash::addData(const QByteArray &data) {
     p_Impl->addData(data);
 }
 QByteArray AcceleratedCryptographicHash::result() const {
-    return p_Impl->result();
+    // Cache the result for consistent behavior across platforms
+    if (!_resultCached) {
+        _cachedResult = p_Impl->result();
+        _resultCached = true;
+    }
+    return _cachedResult;
 }
 
 void AcceleratedCryptographicHash::reset() {
